<?php
/**
 * StatusNet - the distributed open-source microblogging tool
 * 
 * Handler for queue items of type 'usersum', sends an email summaries
 * to a particular user.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Sample
 * @package   StatusNet
 * @author    Evan Prodromou <evan@status.net>
 * @copyright 2010 StatusNet, Inc.
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html AGPL 3.0
 * @link      http://status.net/
 */

if (!defined('STATUSNET')) {
    exit(1);
}

/**
 * Handler for queue items of type 'usersum', sends an email summaries
 * to a particular user.
 *
 * @category  Email
 * @package   StatusNet
 * @author    Evan Prodromou <evan@status.net>
 * @copyright 2010 StatusNet, Inc.
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html AGPL 3.0
 * @link      http://status.net/
 */

class UserEmailSummaryHandler extends QueueHandler
{
    // Maximum number of notices to include by default. This is probably too much.
    
    const MAX_NOTICES = 30;
    
    /**
     * Return transport keyword which identifies items this queue handler
     * services; must be defined for all subclasses.
     *
     * Must be 8 characters or less to fit in the queue_item database.
     * ex "email", "jabber", "sms", "irc", ...
     *
     * @return string
     */
    
    function transport()
    {
        return 'sitesum';
    }

    /**
     * Send a summary email to the user
     * 
     * @param mixed $object
     * @return boolean true on success, false on failure
     */
    
    function handle($user_id)
    {
        // Skip if they've asked not to get summaries

        $ess = Email_summary_status::staticGet('user_id', $user_id);
	
        if (!empty($ess) && !$ess->send_summary) {
            common_log(LOG_INFO, sprintf('Not sending email summary for user %s by request.', $user_id));
            return true;
        }

        $since_id = null;
	
        if (!empty($ess)) {
            $since_id = $ess->last_summary_id;
        }
	  
        $user = User::staticGet('id', $user_id);

        if (empty($user)) {
            common_log(LOG_INFO, sprintf('Not sending email summary for user %s; no such user.', $user_id));
            return true;
        }
	
        if (empty($user->email)) {
            common_log(LOG_INFO, sprintf('Not sending email summary for user %s; no email address.', $user_id));
            return true;
        }
	
        $profile = $user->getProfile();
	
        if (empty($profile)) {
            common_log(LOG_WARNING, sprintf('Not sending email summary for user %s; no profile.', $user_id));
            return true;
        }
	
        
        

        // XXX: This is risky fingerpoken in der objektvars, but I didn't feel like
        // figuring out a better way. -ESP

        $new_top = null;
	
//        if ($notice instanceof ArrayWrapper) {
//            $new_top = $notice->_items[0]->id;
//        }
	
        $out = new XMLStringer();

//        $out->elementStart('div', array('width' => '100%',
//                                        'style' => 'background-color: #ffffff; border: 4px solid #4c609a; padding: 10px;'));
        
        $out->element('img', array('src' => 'http://prodca.st/theme/Pnzi/logo.png',
                                   'alt' => 'Prodcast'));
        
        $out->elementStart('p');
    	$out->raw(sprintf('Bonjour %s, et merci de faire partie de la communauté Prodcast !', $profile->getBestName()));
        $out->elementEnd('p');
        
        $out->elementStart('div', array('style' => 'color: #ffffff; background-color: #4c609a; font-weight: bold; margin-bottom: 10px; padding: 4px;'));
    	$out->raw(_('Cette semaine sur Prodcast:'));
        $out->elementEnd('div');
        
        $out->elementStart('p');
        $raw = <<<EOT
Il reste encore quelques places pour l'<b>APERODCAST S01 E01</b> qui aura lieu le Jeudi <b>19 Mai à
 partir de 20h</b> dans un lieu encore tenu secret. <br>Indices : Charcuterie, Fromage et Vin !! Pour vous inscrire : <a href="http://bit.ly/lC8FLP" target="_blank">http://bit.ly/lC8FLP</a><br><br>

D'autre part, nous sommes <b>demi-finalistes de Start in Paris</b>, un concours de startups. <b>Nous avons besoin de vous pour passer en finale, donc VOTEZ !!</b> <br><br><a href="http://www.startinparis.com/2011/05/start-in-paris/demi-finalistes-sip-9/">http://www.startinparis.com/2011/05/start-in-paris/demi-finalistes-sip-9/</a><br>
EOT;
        $out->raw($raw);
        $out->elementEnd('p');
        
//        list($products, $more) = Amazon_product::search("Royal Wedding", 1);
//        
//        foreach ($products as $product) {
//            $out->elementStart('a', array('href' => common_local_url('PnziProduct', array('title' => $product->url))));
//            $out->element('img', array('src' => $product->mediumimage,
//                                       'class' => 'photo',
//                                       'title' => $product->title,
//                                       'alt' => $product->title,
//                                       'style' => 'border:none;margin:3px;'));
//            $out->elementEnd('a');
//        }
//        
//        $out->elementStart('p');
//    	$out->raw('Avec une mention spéciale pour :');
//        $out->elementEnd('p');
//        
//        $product = Amazon_product::staticGet('url', "1907332790-knit-your-own-royal-wedding");
        

        
//        $out->elementStart('a', array('href' => 'http://prodca.st/zeb'));
//        $out->element('img', array('src' => 'http://prodca.st/avatar/90-original-tmp20110324145807l.jpg',
//                                       'width' => AVATAR_STREAM_SIZE,
//                                       'height' => AVATAR_STREAM_SIZE,
//                                       'alt' => 'Zeb'));
//        $out->elementEnd('a');
//        
//        $out->elementStart('a', array('href' => 'http://prodca.st/alexislerossignol'));
//        $out->element('img', array('src' => 'http://prodca.st/avatar/54-original-tmp20110310123757l.png',
//                                       'width' => AVATAR_STREAM_SIZE,
//                                       'height' => AVATAR_STREAM_SIZE,
//                                       'alt' => 'Alexis Le Rossignol'));
//        $out->elementEnd('a');
//        
//        $out->elementStart('a', array('href' => 'http://prodca.st/product/B000002MTR-one-hot-minute'));
//        $out->element('img', array('src' => 'http://ec5.images-amazon.com/images/I/61j1ku%2BPodL._SL160_.jpg',
//                                       'alt' => 'One Hot Minute'));
//        $out->elementEnd('a');
        
        
        $out->elementStart('p');
    	$out->raw('Happy Prodcasting ! <br/>Julien et Edouard');
        $out->elementEnd('p');
        
//        $out->elementStart('p');
//    	$out->raw('P.S: n\'oubliez pas de Liker notre <a href="http://www.facebook.com/Prodcaster">page Facebook</a> si vous voulez être sûr de ne pas rater les prochains challenges !');
//        $out->elementEnd('p');
        
        
        
        $out->elementStart('div', array('style' => 'color: #ffffff; background-color: #4c609a; font-weight: bold; margin-bottom: 10px; padding: 4px;'));
    	$out->raw(_('Les derniers Prodcasts:'));
        $out->elementEnd('div');
        
        // $notice = $user->ownFriendsTimeline(0, self::MAX_NOTICES, $since_id);
        
        $notice = Notice::publicStream(0, 10);

        
        if (empty($notice) || $notice->N == 0) {
            common_log(LOG_WARNING, sprintf('Not sending email summary for user %s; no notices.', $user_id));
            return true;
        }
        
        $out->elementStart('table', array('width' => '550px',
                                          'style' => 'border: none; border-collapse: collapse;', 
                                          'cellpadding' => '6'));

        while ($notice->fetch()) {
	    
            $profile = Profile::staticGet('id', $notice->profile_id);
	    
            if (empty($profile)) {
                continue;
            }
	    
            $avatar = $profile->getAvatar(AVATAR_STREAM_SIZE);

            $out->elementStart('tr');
            
            
            if (!empty($notice->reply_to)) {
                continue;
            }

            $notice_product = Notice_product::staticGet('notice_id', $notice->id);
            $product = Amazon_product::staticGet('url', $notice_product->title);
            // XXX: continue;
            // XXX: Use helper function (?)
            
            $out->elementStart('td', array('align' => 'left',
                                           'valign' => 'top',
                                           'style' => 'border-bottom: 1px dotted #C5CEE3; padding: 10px 6px 10px 6px;'));

            $out->element('img', array('src' => $product->mediumimage,
                                               'style' => 'width:96px;height:auto;'));
            $out->elementEnd('td');
            
            
            $out->elementStart('td', array('width' => AVATAR_STREAM_SIZE,
                                           'height' => AVATAR_STREAM_SIZE,
                                           'align' => 'left',
                                           'valign' => 'top',
                                           'style' => 'border-bottom: 1px dotted #C5CEE3; padding: 10px 6px 10px 6px;'));
            $out->element('img', array('src' => ($avatar) ?
                                       $avatar->displayUrl() :
                                       Avatar::defaultImage(AVATAR_STREAM_SIZE),
                                       'width' => AVATAR_STREAM_SIZE,
                                       'height' => AVATAR_STREAM_SIZE,
                                       'alt' => $profile->getBestName()));
            $out->elementEnd('td');
            $out->elementStart('td', array('align' => 'left',
                                           'valign' => 'top',
                                           'style' => 'border-bottom: 1px dotted #C5CEE3; padding: 10px 6px 10px 6px;'));
            $out->element('a', array('href' => $profile->profileurl),
                          $profile->nickname);
            $out->text(' ');
            
            $activity_title = new ActivityTitle($out, $notice, $notice_product, $product);
            $activity_title->show();
            
            if ($notice->rendered) {
                $out->raw("<br/>");
                $out->raw($notice->rendered);
            }
            $out->elementStart('div', array('style' => 'font-size: 0.8em; padding-top: 4px;'));

//            $noticeurl = $notice->bestUrl();
            
            $suh = new ShortUrlHash();
            $suh->id = $notice->id;
            $suh->encode();
            
            $noticeurl = common_local_url('ShortUrl',
                                          array('hash' => $suh->hash));
            // above should always return an URL
            assert(!empty($noticeurl));
            $out->elementStart('a', array('rel' => 'bookmark',
                                          'href' => $noticeurl));
            $dt = common_date_iso8601($notice->created);
            $out->element('abbr', array('style' => 'border-bottom: none;',
                                        'title' => $dt),
                          common_date_string($notice->created));
            $out->elementEnd('a');
//            if ($notice->hasConversation()) {
//                $conv = Conversation::staticGet('id', $notice->conversation);
//                $convurl = $conv->uri;
//                if (!empty($convurl)) {
//                    $out->text(' ');
//                    $out->element('a',
//                                  array('href' => $convurl.'#notice-'.$notice->id),
//                                  _('in context'));
//                }
//            }
            $out->elementEnd('div');
            $out->elementEnd('td');
            
            
            $out->elementEnd('tr');
        }
	
        $out->elementEnd('table');

//        $out->raw(sprintf(_('<p><a href="%1s">change your email settings for %2s</a></p>'),
//                          common_local_url('emailsettings'),
//                          common_config('site', 'name')));

//        $out->elementEnd('div');
	
        $body = $out->getString();
	
        // FIXME: do something for people who don't like HTML email
	
        mail_to_user($user, _('Cette semaine sur Prodcast !'), $body,
                     array('Content-Type' => 'text/html; charset=UTF-8'));

        if (empty($ess)) {
	    
            $ess = new Email_summary_status();
	    
            $ess->user_id         = $user_id;
            $ess->created         = common_sql_now();
            $ess->last_summary_id = $new_top;
            $ess->modified        = common_sql_now();

            $ess->insert();
	    
        } else {
	    
            $orig = clone($ess);
	    
            $ess->last_summary_id = $new_top;
            $ess->modified        = common_sql_now();

            $ess->update($orig);
        }
	
        return true;
    }
}
