<?php
/**
 * StatusNet - the distributed open-source microblogging tool
 * Copyright (C) 2009, StatusNet, Inc.
 *
 * PHP version 5
 *
 * Fancybox integration into StatusNet
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Plugin
 * @author    Julien Chaumond <julien@pnzi.com>
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html AGPL 3.0
 * @link      http://status.net/
 */

if (!defined('STATUSNET')) {
    exit(1);
}


/**
 * Fancybox for StatusNet
 *
 * Add the following line to your config.php
 * Parameters should be pretty self-explanatory.
 *
 *     addPlugin('Fancybox', array('demo' => true, 'on_actions' => array('doc')));
 *
 * @category  Plugin
 * @author    Julien Chaumond <julien@pnzi.com>
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html AGPL 3.0
 */


class FancyboxPlugin extends Plugin
{
    public $demo = null;
    public $on_actions = null;
    public $add_transitions = null;
    
    
    function onEndShowScripts($action)
    {
        // We load Fancybox only when desired
        if (!$this->on_actions || in_array($action->trimmed('action'), $this->on_actions)) {
            $action->script(common_path('local/plugins/Fancybox/fancybox/jquery.fancybox-1.3.0.pack.js'));
            if ($this->add_transitions) {
                $action->script(common_path('local/plugins/Fancybox/fancybox/jquery.easing-1.3.pack.js'));
            }
            
            if ($this->demo) {
                $js = '$(document).ready(function() {
                    	$("a#various1").fancybox({
                    		\'hideOnContentClick\': true
                    	});
                    });';
                $action->inlineScript($js);
            }
        }
    }
    
    
    function onEndShowStyles($action)
    {
        // We load Fancybox only when desired
        if (!$this->on_actions || in_array($action->trimmed('action'), $this->on_actions)) {
            $action->cssLink('local/plugins/Fancybox/fancybox/jquery.fancybox-1.3.0.css');
        }
        return true;
    }
    
    
    function onEndShowSections($action)
    {
        if ($this->demo) {
            $action->elementStart('div', array('class' => 'section',
                                               'id' => "aaa"));
            $action->element('h2', null, "Fancybox demo");
            $action->elementStart('ul');
            $action->elementStart('li');
            $action->raw('<a title="Lorem ipsum dolor sit amet" href="#inline1" id="various1">Inline</a>');
            $action->elementEnd('li');
            $action->elementEnd('ul');
            $action->elementEnd('div');
        }
        
        return true;
    }
    
    
    function onEndShowFooter($action)
    {
        if ($this->demo) {
            $action->raw('<div style="display: none;">
                    		<div id="inline1" style="width:400px;height:100px;overflow:auto;">
                    			Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam quis mi eu elit tempor facilisis id et neque. Nulla sit amet sem sapien. Vestibulum imperdiet porta ante ac ornare. Nulla et lorem eu nibh adipiscing ultricies nec at lacus. Cras laoreet ultricies sem, at blandit mi eleifend aliquam. Nunc enim ipsum, vehicula non pretium varius, cursus ac tortor. Vivamus fringilla congue laoreet. Quisque ultrices sodales orci, quis rhoncus justo auctor in. Phasellus dui eros, bibendum eu feugiat ornare, faucibus eu mi. Nunc aliquet tempus sem, id aliquam diam varius ac. Maecenas nisl nunc, molestie vitae eleifend vel, iaculis sed magna. Aenean tempus lacus vitae orci posuere porttitor eget non felis. Donec lectus elit, aliquam nec eleifend sit amet, vestibulum sed nunc.
                    		</div>
                    	</div>');
        }
        
        return true;
    }
    
    
    function onPluginVersion(&$versions)
    {
        $versions[] = array('name' => 'FancyboxPlugin',
                            'version' => '0.1',
                            'author' => 'Julien Chaumond',
                            'homepage' => 'http://status.net/wiki/Plugin:Fancybox',
                            'rawdescription' =>
                            _m('Fancybox for StatusNet.'));
        return true;
    }


}

