<?php
/**
 * StatusNet, the distributed open-source microblogging tool
 *
 * Javascript tabbed navigation (i.e., all tabs on a single page) in StatusNet.
 *
 * PHP version 5
 *
 * LICENCE: This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Plugin
 * @package   StatusNet
 * @author    Julien Chaumond <julien@pnzi.com>
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
 * @link      http://status.net/
 */

if (!defined('STATUSNET')) {
    exit(1);
}



class TabbedNavPlugin extends Plugin
{
    // Whether to add an example tabbed action (TabbedNavExample) at /tabbed-doc
    public $demo = true;
    
    // List of actions on which tabbed nav is enabled (passed from config.php)
    public $on_actions = array('TabbedNavExample');

    
    
    function onEndShowJQueryScripts($action)
    {
        if (in_array($action->trimmed('action'), $this->on_actions)) {
            $action->script(common_path('local/plugins/TabbedNav/tabbednav.js'));
        }
        return true;
    }
    
    
    function onEndShowStyles($action)
    {
        // CSS to hide inactive tabs, using the off-left technique
        
        if (in_array($action->trimmed('action'), $this->on_actions)) {
            $action->style('.ui-tabs-hide { position:absolute; left:-10000px; }');
        }
        return true;
    }
    
    
    
    function onPluginVersion(&$versions)
    {
        $versions[] = array('name' => 'TabbedNav',
                            'version' => '0.1',
                            'author' => 'Julien Chaumond',
                            'homepage' => 'http://status.net/wiki/Plugin:TabbedNav',
                            'rawdescription' =>
                            _m('Plugin to enable tabbed navigation on a single page with javascript.'));
        return true;
    }
    
    
    // Following two hooks: Example action, to illustrate how to use this plugin
    // Example use case: tabbed documentation
    
    function onAutoload($cls)
    {
        $dir = dirname(__FILE__);
        
        if ($cls == 'TabbedNavExampleAction') {
            include_once $dir . '/' . mb_substr($cls, 0, -6) . '.php';
            return false;
        }
        
        return true;
    }
    
    function onStartInitializeRouter($m)
    {
        if ($this->demo) {
            $m->connect('tabbed-doc', array('action' => 'TabbedNavExample'));
            $m->connect('tabbed-doc/', array('action' => 'TabbedNavExample'));
            // **Before** initializing router, otherwise there is a collision with ':nickname'
        }
        return true;
    }
    
}

