<?php
/**
 * StatusNet, the distributed open-source microblogging tool
 *
 * Tabbed navigation Menu example
 *
 * PHP version 5
 *
 * LICENCE: This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Menu
 * @package   StatusNet
 * @author    Evan Prodromou <evan@status.net>
 * @copyright 2008 StatusNet, Inc.
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
 * @link      http://status.net/
 */

if (!defined('STATUSNET') && !defined('LACONICA')) {
    exit(1);
}

require_once INSTALLDIR.'/lib/widget.php';

/**
 * Tabbed nav Menu example
 *
 * @category Output
 * @package  StatusNet
 * @author   Julien Chaumond <julien@pnzi.com>
 * @license  http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
 * @link     http://status.net/
 *
 * @see      Widget
 */


class TabbedNav extends Widget
{
    var $action = null;
    var $q = null;

    /**
     * Construction
     *
     * @param Action $action current action, used for output
     */

    function __construct($action=null, $q = null)
    {
        parent::__construct($action);
        $this->action = $action;
        $this->q = $q;
    }

    /**
     * Show the menu
     *
     * @return void
     */

    function show()
    {
        $action_name = $this->action->trimmed('action');
        $this->action->elementStart('ul', array('class' => 'nav'));
        $args = array();
        if ($this->q) {
            $args['q'] = $this->q;
        }
        
        // common_local_url's 4th parameter is for the URL #fragment
        
        $this->out->menuItem(common_local_url($action_name, $args, null, "Help"), 
            _m('Help'),
            _m('See Help'), true, 'nav_Help');
        $this->out->menuItem(common_local_url($action_name, $args, null, "About"), 
            _m('About'),
            _m('See About'), false, 'nav_About');
        $this->out->menuItem(common_local_url($action_name, $args, null, "FAQ"), 
            _m('FAQ'),
            _m('See FAQ'), false, 'nav_FAQ');
        $this->out->menuItem(common_local_url($action_name, $args, null, "Privacy"), 
            _m('Privacy'),
            _m('See Privacy'), false, 'nav_Privacy');
        $this->out->menuItem(common_local_url($action_name, $args, null, "Source"), 
            _m('Source'),
            _m('See Source'), false, 'nav_Source');
        
        $this->action->elementEnd('ul');
    }
}

