<?php

if (!defined('STATUSNET') && !defined('LACONICA')) {
    exit(1);
}

require_once INSTALLDIR.'/lib/widget.php';

/**
 * Rating stars widget
 *
 * @category Output
 * @package  StatusNet
 * @author   Julien Chaumond <julien@pnzi.com>
 * @license  http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
 * @link     http://status.net/
 *
 * @see      Widget
 */


class RatingStars extends Widget
{
    var $title = null;
    var $rating = null;
    var $nbvotes = null;
    

    /**
     * Construction
     *
     * @param Action $action current action, used for output
     */

    function __construct($action=null, $title=null)
    {
        parent::__construct($action);
        $this->title = $title;
        
        $tag_rating = Tag_rating::getRating($title);
        
        $this->nbvotes = $tag_rating['count'];
        $this->rating  = round($tag_rating['avg'], 2);
    }


    /**
     * Show the widget for rating
     *
     * @return void
     */

    function show()
    {
        $this->out->elementStart('span', array('id' => 'ratingstars'));
        
        // We temporarily prevent spaces from XMLWriter,
        // whatever the value of $config['site']['indent'] is (or there could be undesired spaces).
        
        $this->out->xw->setIndent(false);
        
        $this->out->element('img', array('src' => common_path('local/plugins/TagRating/images/blank.png'),
                                    'class' => 'star',
                                    'style' => 'width:10px;height:30px;'));
        
        for ($i=1; $i <= $this->rating; $i++) {
            $this->showOneStar($i, '1');
        }
        if ($this->rating-$i+1 >= 0.5) {
            $this->showOneStar($i, '05');
            $i++;
        }
        for (; $i<=5; $i++) {
            $this->showOneStar($i, '0');
        }
        
        $this->out->elementStart('span', array('id' => 'textrating',
                                          'class' => 'hreview-aggregate'));
        
        $this->out->element('span', array('class' => 'item',
                                     'style' => 'display:none;'), 
                               $this->title);
        
        $this->out->element('span', array('class' => 'rating'), 
                                    $this->rating);
        $this->out->text('/5');
        
        $this->out->raw('&nbsp;&nbsp;');
        
        $this->out->elementStart('span', array('class' => 'votecount'));
        $this->out->text('(');
        
        // Should we use hreview-aggregate count or votes?
        $this->out->element('span', array('class' => 'count'), 
                                    $this->nbvotes);
        
        // Plural localized string
        $this->out->text(_m(' review', ' reviews', $this->nbvotes));
        $this->out->text(')');
        $this->out->elementEnd('span');
        
        $this->out->xw->setIndent(true);
        
        $this->out->elementEnd('span');
        
        $this->out->elementEnd('span');
    }
    
    
    
    function showOneStar($i, $star)
    {
        $this->out->element('img', array('id' => 'star'.$i,
                                        'src' => common_path('local/plugins/TagRating/images/star'.$star.'.gif'),
                                        'class' => 'star',
                                        'alt' => $i.'/5',
                                        'title' => $i.'/5'));
    }
}
