<?php
/**
 * tipsy  - Facebook-style tooltip plugin for jQuery - integration to StatusNet
 *
 * PHP version 5
 *
 * LICENCE: This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Plugin
 * @package   StatusNet
 * @author    Julien Chaumond <julien@pnzi.com>
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
 * @link      http://status.net/
 * @link      http://pnzi.com/
 */

if (!defined('STATUSNET')) {
    exit(1);
}


/**
 * tipsy  - Facebook-style tooltip plugin for jQuery - integration to StatusNet
 *
 * Adds a tooltip to links having attribute "tipsy"
 *
 * Tipsy: @see http://onehackoranother.com/projects/jquery/tipsy/
 *
 * @category Plugin
 * @package  StatusNet
 * @author   Julien Chaumond <julien@pnzi.com>
 * @license  http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
 * @link     http://status.net/
 */

class TipsyPlugin extends Plugin
{
    public $tipsy = "1.0.0a";
    
    // Off the bleeding edge - till 1.0 is out
    
    
    
    function onEndShowStyles($action)
    {
        $action->cssLink(sprintf('local/plugins/Tipsy/tipsy-%s/stylesheets/tipsy.css', $this->tipsy));
        
        // Make font slightly larger
        
        $action->style('.tipsy { font-size: 11px; } ');
        
        // "Onboard" thingy, on "north" tooltips
        $action->style('.tipsy-n { font-size: 15px; } #logintooltip { right:266px; position: relative; }');
        
        // XXX: We would need to be able to specify a class to the tooltip! Raise issue upstream.
        
        return true;
    }
    
    
    function onEndShowScripts($action)
    {
        $action->script(common_path(sprintf('local/plugins/Tipsy/tipsy-%s/javascripts/jquery.tipsy.js', $this->tipsy)));
        
        $js  = '  $(document).ready(function() {';
        
        // $js .= '    $("a[rel~=tipsy]").tipsy({gravity: "nw"});';
        // "Explicit way": Attribute rel contains word tipsy
        
        // "Implicit way":
        
        $js .= '    $(".product-users a").tipsy({gravity: "s", live: true});';
        $js .= '    $(".vcard a").tipsy({gravity: "s", live: true});';
        // XXX: Unify these two rules and improve their selection performance.
        
        // Needed some CSS adjustments (display:block or inline-block on images) to have acceptable results.
        
        
        $js .= '    $("input#fullname").tipsy({trigger: "manual", gravity: "w", fallback: "Vrai nom conseillé !"})';
        $js .=                        '.hover(function() { $(this).tipsy("show"); }, function() { if (!$(this).hasClass("focus")) $(this).tipsy("hide"); })';
        $js .=                        '.focus(function() { $(this).addClass("focus").tipsy("show"); })';
        $js .=                        '.focusout(function() { $(this).removeClass("focus").tipsy("hide"); });';
        // Lots of work needed to trigger tipsy both on hover and focus. Raise issue upstream.
        
        $js .= '    $("input#newname").tipsy({trigger: "focus", gravity: "w", fallback: "Only letters, numbers, underscores."});';
        
        $js .= '    $("label.checkbox img").tipsy({gravity: "s", live: true});';
        
        $js .= '    $(".product-gallery-item img").tipsy({gravity: "s"});';
        
        $js .= '  });';
        
        // Compress the bugger down a bit
        
        $js = str_replace('  ', '', $js);
        
        $action->inlineScript($js);
        
        return true;
    }
    
    
    function onPluginVersion(&$versions)
    {
        $versions[] = array('name' => 'Tipsy',
                            'version' => '0.1',
                            'author' => 'Julien Chaumond',
                            'homepage' => 'http://status.net/wiki/Plugin:Tipsy',
                            'rawdescription' =>
                            _m('tipsy  - Facebook-style tooltip plugin for jQuery - integration to StatusNet'));
        return true;
    }
}

