<?php
/**
 * StatusNet, the distributed open-source microblogging tool
 *
 * Plugin to add picture (avatar) import and linkback to profile to Twitter and Facebook plugins
 *
 * PHP version 5
 *
 * LICENCE: This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Plugin
 * @package   StatusNet
 * @author    Julien Chaumond <chaumond@gmail.com>
 * @copyright 2010   Julien Chaumond
 * @license   http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
 * @link      http://status.net/
 */

if (!defined('STATUSNET') && !defined('LACONICA')) {
    exit(1);
}

class TwitterAndFacebookAdvancedPlugin extends Plugin
{
    function __construct()
    {
        parent::__construct();
    }

    
    function onStartProfilePageActionsElements($userprofile, $profile)
    {
        // $userprofile: UserProfile widget
        // &$profile: the profile being shown
        
        $flink = Foreign_link::getByUserID($profile->id, FACEBOOK_CONNECT_SERVICE);
        
        // Foreign_user doesn't seem to be implemented in Facebook plugin.
        if (!empty($flink)) {
            $userprofile->elementStart('li');
            $userprofile->element('a', array('class' => 'taglinkfacebook',
                                             'href' => 'http://www.facebook.com/profile.php?id='.$flink->foreign_id,
                                             'title' => _m('See profile on Facebook')),
                                       _m('Facebook'));
            $userprofile->elementEnd('li');
        }
        
        unset($flink);
        
        $flink = Foreign_link::getByUserID($profile->id, TWITTER_SERVICE);
        // We could probably save a DB hit, but hey, it's cheap
        
        if (!empty($flink)) {
            $fuser = $flink->getForeignUser();
            
            if (!empty($fuser)) {
                $userprofile->elementStart('li');
                $userprofile->element('a', array('class' => 'taglinktwitter',
                                                 'href' => $fuser->uri, 
                                                 'title' => _m('See profile on Twitter')),
                                           _m('Twitter'));
                // We could use $fuser->nickname

                $userprofile->elementEnd('li');
            }
        }
        
        return true;
    }
    
    
    
    function onTwitterNewUserImage($user, $image_url)
    {
        $fileExt = substr($image_url, strrpos($image_url, '.') - 1);
        
        $filename = Avatar::filename($user->id,
                                     $fileExt,
                                     null,
                                     'tmp'.common_timestamp());
        
        $this->saveExternalImage(&$user, $image_url, $filename);
    }
    
    
    function onFacebookNewUserImage($user, $image_url)
    {
        $filename = Avatar::filename($user->id,
                                         ".jpeg",
                                         null,
                                         'tmp'.common_timestamp());
        
        $this->saveExternalImage(&$user, $image_url, $filename);
    }
    
    
    
    function saveExternalImage(&$user, $image_url, $filename)
    {
        // @see actions/avatarsettings.php and classes/Avatar.php
        
        $ch = curl_init($image_url);
        $fp = fopen(Avatar::path($filename), "w");
        curl_setopt($ch, CURLOPT_FILE, $fp);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_exec($ch);
        curl_close($ch);
        fclose($fp);
        
        if (file_exists(Avatar::path($filename))) {
            $profile = $user->getProfile();
            $profile->setOriginal($filename);
            // setOriginal() takes care of the resizing
        }
    }
    
    
    
    /**
     * Add a Facebook queue item for each notice
     *
     * @param Notice $notice      the notice
     * @param array  &$transports the list of transports (queues)
     *
     * @return boolean hook return
     */
    // @see  TwitterBridgePlugin.php
    /*
    function onStartEnqueueNotice($notice, &$transports)
    {
        // We can't get updates from Facebook, so there is no possible loop
        fdfdfd();
        array_push($transports, 'facebook');
        return true;
    }
    */
    

    function onPluginVersion(&$versions)
    {
        $versions[] = array('name' => 'TwitterAndFacebookAdvanced',
                            'version' => '0.1',
                            'author' => 'Julien Chaumond',
                            'homepage' => 'http://status.net/wiki/Plugin:TwitterAndFacebookAdvanced',
                            'rawdescription' =>
                            _m('Plugin to add picture (avatar) import and linkback to profile to Twitter and Facebook plugins.'));
        return true;
    }
    
    
    
    function onEndShowSections($action)
    {
        // Not <fb:like-box>, which for some reason does not support CSS customization
        
//        $action->element('fb:fan', array('profile_id' => '135774646433454',
//                                          'width' => '235',
//                                          'height' => '165',
//                                          'connections' => '4',
//                                          'stream' => 'false',
//                                          'header' => 'false'));

        // XXX: CSS Styling
        
//        $action->raw('<iframe src="http://www.facebook.com/plugins/fan.php?id=135774646433454&amp;width=240&amp;connections=4&amp;stream=false&amp;header=false&amp;height=165" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:240px; height:255px;" allowTransparency="true"></iframe>');
        
        // fan.php instead of likebox.php for now.
        
        return true;
    }
}
