#!/usr/bin/env php
<?php
/*
 * StatusNet - a distributed open-source microblogging tool
 * Copyright (C) 2008, 2009, StatusNet, Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

define('INSTALLDIR', realpath(dirname(__FILE__) . '/..'));

$shortoptions = 'i:n:';
$longoptions = array('id=', 'nickname=');

$helptext = <<<END_OF_RESENDMAILCONFIRM_HELP
resendmailconfirm.php [options]
Resend email address confirm code to user that has not confirmed yet.

  -i --id       id of the user to query
  -n --nickname nickname of the user to query

END_OF_RESENDMAILCONFIRM_HELP;

require_once INSTALLDIR.'/scripts/commandline.inc';

if (have_option('i', 'id')) {
    $id = get_option_value('i', 'id');
    $user = User::staticGet('id', $id);
    if (empty($user)) {
        print "Can't find user with ID $id\n";
        exit(1);
    }
} else if (have_option('n', 'nickname')) {
    $nickname = get_option_value('n', 'nickname');
    $user = User::staticGet('nickname', $nickname);
    if (empty($user)) {
        print "Can't find user with nickname '$nickname'\n";
        exit(1);
    }
} else {
    print "You must provide either an ID, or a nickname.\n";
    exit(1);
}


if (!empty($user)) {
    if (empty($user->email)) {
        # Check for unconfirmed emails
        $unconfirmed_email = new Confirm_address();
        $unconfirmed_email->user_id = $user->id;
        $unconfirmed_email->address_type = 'email';
        $unconfirmed_email->find(true);
        
        if (empty($unconfirmed_email->address)) {
            print "No email registered for user '$user->nickname'\n";
        } else {
            mail_confirm_address($user, $unconfirmed_email->code, $user->nickname, $unconfirmed_email->address);
            print "Sent mail confirm to Adress: $unconfirmed_email->address\n";
        }
    } else {
        print "User '$user->nickname' already has a confirmed email\n";
    }
    exit(0);
}
